@@ -36,20 +36,20 @@
 #define START_LOCALE_SWITCH							\
 	do {									\
 		if (gfs->locale) {						\
-			go_currency_date_format_shutdown ();			\
+			_go_currency_date_format_shutdown ();			\
 			oldlocale = g_strdup (setlocale (LC_ALL, NULL));	\
 			go_setlocale (LC_ALL, gfs->locale);			\
-			go_currency_date_format_init ();			\
+			_go_currency_date_format_init ();			\
 		}								\
 	} while (0)
 
 #define END_LOCALE_SWITCH							\
 	do {									\
 		if (oldlocale) {						\
-			go_currency_date_format_shutdown ();			\
+			_go_currency_date_format_shutdown ();			\
 			go_setlocale (LC_ALL, oldlocale);			\
 			g_free (oldlocale);					\
-			go_currency_date_format_init ();			\
+			_go_currency_date_format_init ();			\
 		}								\
 	} while (0)
 
@@ -100,7 +100,7 @@ typedef enum {
 
 struct  _GOFormatSel {
 	GtkHBox   box;
-	GladeXML *gui;
+	GtkBuilder *gui;
 
 	gpointer  value;
 	char	 *locale;
@@ -371,7 +371,7 @@ find_builtin (const char *fmtstr, int page, gboolean def)
 	if (page == GO_FORMAT_UNKNOWN)
 		return NULL;
 
-	candidates = go_format_builtins[page];
+	candidates = _go_format_builtins[page];
 	if (!candidates)
 		return NULL;
 
@@ -560,7 +560,7 @@ stays:
 			gtk_list_store_clear (gfs->format.formats.model);
 			for (; start <= end ; ++start)
 				fmt_dialog_init_fmt_list (gfs,
-					go_format_builtins[start], &select);
+					_go_format_builtins[start], &select);
 
 			/* If this is the custom page and the format has
 			* not been found append it */
@@ -569,9 +569,15 @@ stays:
 			*      the std formats and the custom formats in the GOFormat hash.
 			*/
 			if  (page == FMT_CUSTOM && select.stamp == 0) {
-				char *tmp = go_format_str_localize (go_format_as_XL (gfs->format.spec));
-				format_entry_set_text (gfs, tmp);
-				g_free (tmp);
+				const char *fmtstr = go_format_as_XL (gfs->format.spec);
+				char *tmp = go_format_str_localize (fmtstr);
+				if (tmp) {
+					format_entry_set_text (gfs, tmp);
+					g_free (tmp);
+				} else {
+					g_warning ("Localization of %s failed.",
+						   fmtstr);
+				}
 			} else if (select.stamp == 0)
 				if (!gtk_tree_model_get_iter_first (
 					GTK_TREE_MODEL (gfs->format.formats.model),
@@ -744,8 +750,8 @@ cb_format_currency_select (G_GNUC_UNUSED GtkWidget *ct,
 	if (!gfs->enable_edit || new_text == NULL || *new_text == '\0')
 		return FALSE;
 
-	for (i = 0; go_format_currencies[i].symbol != NULL ; ++i) {
-		GOFormatCurrency const *ci = go_format_currencies + i;
+	for (i = 0; _go_format_currencies[i].symbol != NULL ; ++i) {
+		GOFormatCurrency const *ci = _go_format_currencies + i;
 		if (!strcmp (_(ci->description), new_text)) {
 			gfs->format.details.currency = ci;
 			break;
@@ -948,21 +954,17 @@ nfs_init (GOFormatSel *gfs)
 	GOFormatFamily page;
 
 	GtkWidget *toplevel;
-	GtkWidget *old_parent;
 
 	gfs->enable_edit = FALSE;
 	gfs->show_format_with_markup = FALSE;
 	gfs->locale = NULL;
 
-	gfs->gui = go_glade_new ("go-format-sel.glade", NULL, GETTEXT_PACKAGE, NULL);
+	gfs->gui = go_gtk_builder_new ("go-format-sel.ui", GETTEXT_PACKAGE, NULL);
 	if (gfs->gui == NULL)
 		return;
 
-	toplevel = glade_xml_get_widget (gfs->gui, "number_box");
-	old_parent = gtk_widget_get_toplevel (toplevel);
-	gtk_widget_reparent (toplevel, GTK_WIDGET (gfs));
-	gtk_widget_destroy (old_parent);
-	gtk_widget_queue_resize (toplevel);
+	toplevel = go_gtk_builder_get_widget (gfs->gui, "number_box");
+	gtk_box_pack_start (GTK_BOX (gfs), toplevel, TRUE, TRUE, 0);
 
 	gfs->format.spec = go_format_general ();
 	go_format_ref (gfs->format.spec);
@@ -975,8 +977,8 @@ nfs_init (GOFormatSel *gfs)
 
 	study_format (gfs);
 
-	gfs->format.preview_box = glade_xml_get_widget (gfs->gui, "preview_box");
-	gfs->format.preview = GTK_TEXT_VIEW (glade_xml_get_widget (gfs->gui, "preview"));
+	gfs->format.preview_box = go_gtk_builder_get_widget (gfs->gui, "preview_box");
+	gfs->format.preview = GTK_TEXT_VIEW (gtk_builder_get_object (gfs->gui, "preview"));
 	{
 		PangoFontMetrics *metrics;
 		PangoContext *context;
@@ -994,12 +996,14 @@ nfs_init (GOFormatSel *gfs)
 	}
 	gfs->format.preview_buffer = gtk_text_view_get_buffer (gfs->format.preview);
 
-	gfs->format.menu = glade_xml_get_widget (gfs->gui, "format_menu");
+	gfs->format.menu = go_gtk_builder_get_widget (gfs->gui, "format_menu");
 	populate_menu (gfs);
 
 	/* Collect all the required format widgets and hide them */
 	for (i = 0; (name = widget_names[i]) != NULL; ++i) {
-		tmp = glade_xml_get_widget (gfs->gui, name);
+		if (i == F_SYMBOL)
+			continue;
+		tmp = go_gtk_builder_get_widget (gfs->gui, name);
 
 		if (tmp == NULL) {
 			g_warning ("nfs_init : failed to load widget %s", name);
@@ -1011,6 +1015,9 @@ nfs_init (GOFormatSel *gfs)
 		gfs->format.widget[i] = tmp;
 	}
 
+	gfs->format.widget[F_SYMBOL] = go_combo_text_new (NULL);
+	gtk_widget_hide (gfs->format.widget[F_SYMBOL]);
+
 	/* set minimum heights */
 	gtk_widget_set_size_request (gfs->format.widget[F_LIST], -1, 100);
 	gtk_widget_set_size_request (gfs->format.widget[F_NEGATIVE], -1, 100);
@@ -1082,8 +1089,8 @@ nfs_init (GOFormatSel *gfs)
 		GSList *ptr, *l = NULL;
 		const char *desc;
 
-		for (i = 0; go_format_currencies[i].symbol != NULL ; ++i)
-			l = g_slist_prepend (l, _((gchar *)go_format_currencies[i].description));
+		for (i = 0; _go_format_currencies[i].symbol != NULL ; ++i)
+			l = g_slist_prepend (l, _((gchar *)_go_format_currencies[i].description));
 		l = g_slist_sort (l, funny_currency_order);
 
 		for (ptr = l; ptr != NULL ; ptr = ptr->next)
@@ -1100,8 +1107,11 @@ nfs_init (GOFormatSel *gfs)
 		g_signal_connect (G_OBJECT (combo), "entry_changed",
 			G_CALLBACK (cb_format_currency_select), gfs);
 		gtk_label_set_mnemonic_widget (
-			GTK_LABEL (glade_xml_get_widget (gfs->gui, "format_symbol_label")),
+			GTK_LABEL (gtk_builder_get_object (gfs->gui, "format_symbol_label")),
 			GTK_WIDGET (combo));
+		/* add the combo to its container */
+		gtk_box_pack_start (GTK_BOX (gtk_builder_get_object (gfs->gui, "format_symbol_box")),
+				    GTK_WIDGET (combo), TRUE, TRUE, 0);
 	}
 
 	/* Setup special handler for Custom */
