@@ -23,7 +23,6 @@
 #include "gog-xy.h"
 #include <goffice/graph/gog-view.h>
 #include <goffice/graph/gog-renderer.h>
-#include <goffice/graph/gog-style.h>
 #include <goffice/graph/gog-theme.h>
 #include <goffice/graph/gog-axis.h>
 #include <goffice/graph/gog-error-bar.h>
@@ -38,6 +37,8 @@
 #include <goffice/math/go-math.h>
 #include <goffice/utils/go-line.h>
 #include <goffice/utils/go-persist.h>
+#include <goffice/utils/go-style.h>
+#include <goffice/utils/go-styled-object.h>
 #include <goffice/app/module-plugin-defs.h>
 
 #ifdef GOFFICE_WITH_GTK
@@ -99,30 +100,29 @@ gog_2d_plot_update (GogObject *obj)
 		if (!gog_series_is_valid (GOG_SERIES (series)))
 			continue;
 
-		go_data_vector_get_minmax (GO_DATA_VECTOR (
-			series->base.values[1].data), &tmp_min, &tmp_max);
+		go_data_get_bounds (series->base.values[1].data, &tmp_min, &tmp_max);
 		if (y_min > tmp_min) y_min = tmp_min;
 		if (y_max < tmp_max) y_max = tmp_max;
 		if (model->y.fmt == NULL)
 			model->y.fmt = go_data_preferred_fmt (series->base.values[1].data);
+		model->y.date_conv = go_data_date_conv (series->base.values[1].data);
 
 		if (series->base.values[0].data != NULL) {
-			go_data_vector_get_minmax (GO_DATA_VECTOR (
-				series->base.values[0].data), &tmp_min, &tmp_max);
+			go_data_get_bounds (series->base.values[0].data, &tmp_min, &tmp_max);
 
 			if (!go_finite (tmp_min) || !go_finite (tmp_max) ||
 			    tmp_min > tmp_max) {
 				tmp_min = 0;
-				tmp_max = go_data_vector_get_len (
-					GO_DATA_VECTOR (series->base.values[1].data));
+				tmp_max = go_data_get_vector_size (series->base.values[1].data);
 
 				is_discrete = TRUE;
 			} else if (model->x.fmt == NULL)
 				model->x.fmt = go_data_preferred_fmt (series->base.values[0].data);
+
+			model->x.date_conv = go_data_date_conv (series->base.values[0].data);
 		} else {
 			tmp_min = 0;
-			tmp_max = go_data_vector_get_len (
-				GO_DATA_VECTOR (series->base.values[1].data));
+			tmp_max = go_data_get_vector_size (series->base.values[1].data);
 			is_discrete = TRUE;
 		}
 
@@ -191,6 +191,8 @@ gog_2d_plot_axis_get_bounds (GogPlot *plot, GogAxisType axis,
 			!go_finite (model->x.maxima);
 		if (bounds->fmt == NULL && model->x.fmt != NULL)
 			bounds->fmt = go_format_ref (model->x.fmt);
+		if (model->x.date_conv)
+			bounds->date_conv = model->x.date_conv;
 
 		for (ptr = plot->series; ptr != NULL ; ptr = ptr->next)
 			if (gog_series_is_valid (GOG_SERIES (ptr->data)))
@@ -203,6 +205,8 @@ gog_2d_plot_axis_get_bounds (GogPlot *plot, GogAxisType axis,
 		bounds->val.maxima = model->y.maxima;
 		if (bounds->fmt == NULL && model->y.fmt != NULL)
 			bounds->fmt = go_format_ref (model->y.fmt);
+		if (model->y.date_conv)
+			bounds->date_conv = model->y.date_conv;
 	}
 	return NULL;
 }
@@ -248,7 +252,7 @@ gog_2d_plot_init (Gog2DPlot *plot2d)
 
 GSF_DYNAMIC_CLASS (Gog2DPlot, gog_2d_plot,
 	gog_2d_plot_class_init, gog_2d_plot_init,
-	GOG_PLOT_TYPE)
+	GOG_TYPE_PLOT)
 
 enum {
 	GOG_XY_PROP_0,
@@ -260,7 +264,7 @@ enum {
 
 static GogObjectClass *xy_parent_klass;
 
-#define GOG_XY_PLOT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_XY_PLOT_TYPE, GogXYPlotClass))
+#define GOG_XY_PLOT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_TYPE_XY_PLOT, GogXYPlotClass))
 
 static char const *
 gog_xy_plot_type_name (G_GNUC_UNUSED GogObject const *item)
@@ -382,10 +386,10 @@ gog_xy_plot_class_init (GogPlotClass *plot_klass)
 		};
 		plot_klass->desc.series.dim = dimensions;
 		plot_klass->desc.series.num_dim = G_N_ELEMENTS (dimensions);
-		plot_klass->desc.series.style_fields = GOG_STYLE_LINE 
-			| GOG_STYLE_FILL 
-			| GOG_STYLE_MARKER 
-			| GOG_STYLE_INTERPOLATION;
+		plot_klass->desc.series.style_fields = GO_STYLE_LINE 
+			| GO_STYLE_FILL 
+			| GO_STYLE_MARKER 
+			| GO_STYLE_INTERPOLATION;
 	}
 }
 
@@ -405,7 +409,7 @@ GSF_DYNAMIC_CLASS (GogXYPlot, gog_xy_plot,
 
 static GogObjectClass *bubble_parent_klass;
 
-#define GOG_BUBBLE_PLOT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_BUBBLE_PLOT_TYPE, GogBubblePlotClass))
+#define GOG_BUBBLE_PLOT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_TYPE_BUBBLE_PLOT, GogBubblePlotClass))
 
 static void gog_bubble_plot_adjust_bounds (Gog2DPlot *model, double *x_min, double *x_max, double *y_min, double *y_max);
 
@@ -418,13 +422,13 @@ gog_bubble_plot_type_name (G_GNUC_UNUSED GogObject const *item)
 extern gpointer gog_bubble_plot_pref (GogBubblePlot *bubble, GOCmdContext *cc);
 static void
 gog_bubble_plot_populate_editor (GogObject *obj, 
-				 GogEditor *editor,
+				 GOEditor *editor,
 				 G_GNUC_UNUSED GogDataAllocator *dalloc,
 			GOCmdContext *cc)
 {
-	gog_editor_add_page (editor,
-			     gog_bubble_plot_pref (GOG_BUBBLE_PLOT (obj), cc),
-			     _("Properties"));
+	GtkWidget *w = gog_bubble_plot_pref (GOG_BUBBLE_PLOT (obj), cc);
+	go_editor_add_page (editor, w, _("Properties"));
+	g_object_unref (G_OBJECT (w));
 
 	(GOG_OBJECT_CLASS(bubble_parent_klass)->populate_editor) (obj, editor, dalloc, cc);
 }
@@ -551,7 +555,7 @@ gog_bubble_plot_class_init (GogPlotClass *plot_klass)
 		};
 		plot_klass->desc.series.dim = dimensions;
 		plot_klass->desc.series.num_dim = G_N_ELEMENTS (dimensions);
-		plot_klass->desc.series.style_fields = GOG_STYLE_OUTLINE | GOG_STYLE_FILL;
+		plot_klass->desc.series.style_fields = GO_STYLE_OUTLINE | GO_STYLE_FILL;
 	}
 }
 
@@ -595,7 +599,7 @@ enum {
 
 static GogObjectClass *map_parent_klass;
 
-#define GOG_XY_COLOR_PLOT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_XY_COLOR_PLOT_TYPE, GogXYColorPlotClass))
+#define GOG_XY_COLOR_PLOT_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GOG_TYPE_XY_COLOR_PLOT, GogXYColorPlotClass))
 
 static void
 gog_xy_color_plot_clear_formats (GogXYColorPlot *map)
@@ -622,12 +626,12 @@ gog_xy_color_plot_update (GogObject *obj)
 		if (!gog_series_is_valid (GOG_SERIES (series)))
 			continue;
 
-		go_data_vector_get_minmax (GO_DATA_VECTOR (
-			series->base.values[2].data), &tmp_min, &tmp_max);
+		go_data_get_bounds (series->base.values[2].data, &tmp_min, &tmp_max);
 		if (z_min > tmp_min) z_min = tmp_min;
 		if (z_max < tmp_max) z_max = tmp_max;
 		if (model->z.fmt == NULL)
 			model->z.fmt = go_data_preferred_fmt (series->base.values[2].data);
+		model->z.date_conv = go_data_date_conv (series->base.values[2].data);
 	}
 	if (model->z.minima != z_min || model->z.maxima != z_max) {
 		model->z.minima = z_min;
@@ -651,6 +655,8 @@ gog_xy_color_plot_axis_get_bounds (GogPlot *plot, GogAxisType axis,
 			!go_finite (model->z.maxima);
 		if (bounds->fmt == NULL && model->z.fmt != NULL)
 			bounds->fmt = go_format_ref (model->z.fmt);
+		if (model->z.date_conv)
+			bounds->date_conv = model->z.date_conv;
 		return NULL;
 	}
 	return GOG_PLOT_CLASS (map_parent_klass)->axis_get_bounds (plot, axis, bounds);
@@ -675,29 +681,30 @@ hide_outliers_toggled_cb (GtkToggleButton *btn, GObject *obj)
 
 static void 
 gog_xy_color_plot_populate_editor (GogObject *obj,
-				   GogEditor *editor,
+				   GOEditor *editor,
 				   GogDataAllocator *dalloc,
 				   GOCmdContext *cc)
 {
 #ifdef GOFFICE_WITH_GTK
-	GladeXML *gui;
+	GtkBuilder *gui;
 	char const *dir;
 	char *path;
 
 	dir = go_plugin_get_dir_name (go_plugins_get_plugin_by_id ("GOffice_plot_xy"));
-	path = g_build_filename (dir, "gog-xy-color-prefs.glade", NULL);
-	gui = go_libglade_new (path, "gog-xy-color-prefs", GETTEXT_PACKAGE, cc);
+	path = g_build_filename (dir, "gog-xy-color-prefs.ui", NULL);
+	gui = go_gtk_builder_new (path, GETTEXT_PACKAGE, cc);
 	g_free (path);
 
 	if (gui != NULL) {
-		GtkWidget *w = glade_xml_get_widget (gui, "hide-outliers");
+		GtkWidget *w = go_gtk_builder_get_widget (gui, "hide-outliers");
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
 				(GOG_XY_COLOR_PLOT (obj))->hide_outliers);
 		g_signal_connect (G_OBJECT (w),
 			"toggled",
 			G_CALLBACK (hide_outliers_toggled_cb), obj);
-		w = glade_xml_get_widget (gui, "gog-xy-color-prefs");
-		gog_editor_add_page (editor, w, _("Properties"));
+		w = go_gtk_builder_get_widget (gui, "gog-xy-color-prefs");
+		go_editor_add_page (editor, w, _("Properties"));
+		g_object_unref (gui);
 	}
 
 #endif
@@ -808,8 +815,8 @@ gog_xy_color_plot_class_init (GogPlotClass *plot_klass)
 		};
 		plot_klass->desc.series.dim = dimensions;
 		plot_klass->desc.series.num_dim = G_N_ELEMENTS (dimensions);
-		plot_klass->desc.series.style_fields = GOG_STYLE_LINE | GOG_STYLE_MARKER
-			| GOG_STYLE_INTERPOLATION |GOG_STYLE_MARKER_NO_COLOR;
+		plot_klass->desc.series.style_fields = GO_STYLE_LINE | GO_STYLE_MARKER
+			| GO_STYLE_INTERPOLATION |GO_STYLE_MARKER_NO_COLOR;
 	}
 	plot_klass->axis_set	      	= GOG_AXIS_SET_XY_COLOR;
 	plot_klass->axis_get_bounds   	= gog_xy_color_plot_axis_get_bounds;
@@ -866,8 +873,8 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 	GogXYSeries const *series = NULL;
 	unsigned i ,j ,k ,n;
 	GogTheme *theme = gog_object_get_theme (GOG_OBJECT (model));
-	GogStyle *neg_style = NULL;
-	GogStyle *style = NULL;
+	GOStyle *neg_style = NULL;
+	GOStyle *style = NULL;
 	GogViewAllocation const *area;
 	GOPath *path = NULL, *next_path = NULL;
 	GSList *ptr;
@@ -943,14 +950,14 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 		if (n < 1)
 			continue;
 
-		style = gog_styled_object_get_style (GOG_STYLED_OBJECT (series));
+		style = go_styled_object_get_style (GO_STYLED_OBJECT (series));
 
-		show_marks = gog_style_is_marker_visible (style);
-		show_lines = gog_style_is_line_visible (style);
-		show_fill = gog_style_is_fill_visible (style);
+		show_marks = go_style_is_marker_visible (style);
+		show_lines = go_style_is_line_visible (style);
+		show_fill = go_style_is_fill_visible (style);
 
 		if (model->base.vary_style_by_element)
-			style = gog_style_dup (style);
+			style = go_style_dup (style);
 		gog_renderer_push_style (view->renderer, style);
 
 		if ((show_lines || show_fill) && !GOG_IS_BUBBLE_PLOT (model)) {
@@ -980,15 +987,15 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 
 					next_series = ptr->next->data;
 					if (gog_series_is_valid (GOG_SERIES (next_series))) {
-						GogStyle *next_style;
+						GOStyle *next_style;
 						const double *next_x_vals, *next_y_vals;
 						unsigned int next_n_points;
 
 						next_n_points = gog_series_get_xy_data
 							(GOG_SERIES (next_series),
 							 &next_x_vals, &next_y_vals);
-						next_style = gog_styled_object_get_style
-							(GOG_STYLED_OBJECT (next_series));
+						next_style = go_styled_object_get_style
+							(GO_STYLED_OBJECT (next_series));
 
 						next_path = gog_chart_map_make_path
 							(chart_map, next_x_vals, next_y_vals,
@@ -1031,7 +1038,7 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 				break;
 			}
 			gog_renderer_push_style (view->renderer,
-				gog_styled_object_get_style (GOG_STYLED_OBJECT (series->hdroplines)));
+				go_styled_object_get_style (GO_STYLED_OBJECT (series->hdroplines)));
 			drop_path = go_path_new ();
 			go_path_set_options (drop_path, GO_PATH_OPTIONS_SHARP);
 			for (i = 0; i < n; i++) {
@@ -1078,7 +1085,7 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 				break;
 			}
 			gog_renderer_push_style (view->renderer,
-				gog_styled_object_get_style (GOG_STYLED_OBJECT (series->vdroplines)));
+				go_styled_object_get_style (GO_STYLED_OBJECT (series->vdroplines)));
 			drop_path = go_path_new ();
 			go_path_set_options (drop_path, GO_PATH_OPTIONS_SHARP);
 			for (i = 0; i < n; i++) {
@@ -1103,7 +1110,7 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 
 		if (GOG_IS_BUBBLE_PLOT (model)) {
 			double zmin;
-			go_data_vector_get_minmax (GO_DATA_VECTOR (series->base.values[2].data), &zmin, &zmax);
+			go_data_get_bounds (series->base.values[2].data, &zmin, &zmax);
 			show_negatives = GOG_BUBBLE_PLOT (view->model)->show_negatives;
 			if ((! go_finite (zmax)) || (!show_negatives && (zmax <= 0))) continue;
 			rmax = MIN (view->residual.w, view->residual.h) / BUBBLE_MAX_RADIUS_RATIO
@@ -1113,8 +1120,8 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 			if (show_negatives) {
 				zmin = fabs (zmin);
 				if (zmin > zmax) zmax = zmin;
-				neg_style = gog_style_dup (GOG_STYLED_OBJECT (series)->style);
-				neg_style->fill.type = GOG_FILL_STYLE_PATTERN;
+				neg_style = go_style_dup (GOG_STYLED_OBJECT (series)->style);
+				neg_style->fill.type = GO_STYLE_FILL_PATTERN;
 				neg_style->fill.pattern.pattern = GO_PATTERN_SOLID;
 				neg_style->fill.pattern.back = RGBA_WHITE;
 			}
@@ -1167,8 +1174,8 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 							gse = GOG_SERIES_ELEMENT (overrides->data);
 							overrides = overrides->next;
 							gog_renderer_push_style (view->renderer,
-								gog_styled_object_get_style (
-									GOG_STYLED_OBJECT (gse)));
+								go_styled_object_get_style (
+									GO_STYLED_OBJECT (gse)));
 					} else if (model->base.vary_style_by_element)
 						gog_theme_fillin_style (theme, style, GOG_OBJECT (series),
 									model->base.index_num + i - 1, FALSE);
@@ -1245,7 +1252,7 @@ gog_xy_view_render (GogView *view, GogViewAllocation const *bbox)
 							(GOG_SERIES_ELEMENT (overrides->data)->index == k)) {
 								gse = GOG_SERIES_ELEMENT (overrides->data);
 								overrides = overrides->next;
-								style = gog_styled_object_get_style (GOG_STYLED_OBJECT (gse));
+								style = go_styled_object_get_style (GO_STYLED_OBJECT (gse));
 								gog_renderer_push_style (view->renderer, style);
 						}
 						if (is_map) {
@@ -1301,16 +1308,16 @@ gog_xy_view_class_init (GogViewClass *view_klass)
 
 GSF_DYNAMIC_CLASS (GogXYView, gog_xy_view,
 	gog_xy_view_class_init, NULL,
-	GOG_PLOT_VIEW_TYPE)
+	GOG_TYPE_PLOT_VIEW)
 
 /*****************************************************************************/
 
 typedef GogView		GogXYSeriesView;
 typedef GogViewClass	GogXYSeriesViewClass;
 
-#define GOG_XY_SERIES_VIEW_TYPE	(gog_xy_series_view_get_type ())
-#define GOG_XY_SERIES_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_XY_SERIES_VIEW_TYPE, GogXYSeriesView))
-#define IS_GOG_XY_SERIES_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_XY_SERIES_VIEW_TYPE))
+#define GOG_TYPE_XY_SERIES_VIEW	(gog_xy_series_view_get_type ())
+#define GOG_XY_SERIES_VIEW(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_XY_SERIES_VIEW, GogXYSeriesView))
+#define GOG_IS_XY_SERIES_VIEW(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_XY_SERIES_VIEW))
 
 static void
 gog_xy_series_view_render (GogView *view, GogViewAllocation const *bbox)
@@ -1340,7 +1347,7 @@ gog_xy_series_view_class_init (GogXYSeriesViewClass *gview_klass)
 
 GSF_DYNAMIC_CLASS (GogXYSeriesView, gog_xy_series_view,
 	gog_xy_series_view_class_init, NULL,
-	GOG_VIEW_TYPE)
+	GOG_TYPE_VIEW)
 
 /*****************************************************************************/
 
@@ -1394,22 +1401,22 @@ vert_drop_lines_pre_remove (GogObject *parent, GogObject *child)
 
 typedef GogSeriesElement GogXYSeriesElement;
 typedef GogSeriesElementClass GogXYSeriesElementClass;
-#define GOG_XY_SERIES_ELEMENT_TYPE	(gog_xy_series_element_get_type ())
-#define GOG_XY_SERIES_ELEMENT(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_XY_SERIES_ELEMENT_TYPE, GogXYSeriesElement))
-#define IS_GOG_XY_SERIES_ELEMENT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_XY_SERIES_ELEMENT_TYPE))
+#define GOG_TYPE_XY_SERIES_ELEMENT	(gog_xy_series_element_get_type ())
+#define GOG_XY_SERIES_ELEMENT(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_XY_SERIES_ELEMENT, GogXYSeriesElement))
+#define GOG_IS_XY_SERIES_ELEMENT(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_XY_SERIES_ELEMENT))
 GType gog_xy_series_element_get_type (void);
 
 static void
-gog_xy_series_element_init_style (GogStyledObject *gso, GogStyle *style)
+gog_xy_series_element_init_style (GogStyledObject *gso, GOStyle *style)
 {
 	GogSeries const *series = GOG_SERIES (GOG_OBJECT (gso)->parent);
-	GogStyle *parent_style;
+	GOStyle *parent_style;
 
 	g_return_if_fail (series != NULL);
 
-	parent_style = gog_styled_object_get_style (GOG_STYLED_OBJECT (series));
-	if (parent_style->interesting_fields & GOG_STYLE_MARKER)
-		style->interesting_fields = parent_style->interesting_fields & (GOG_STYLE_MARKER | GOG_STYLE_MARKER_NO_COLOR);
+	parent_style = go_styled_object_get_style (GO_STYLED_OBJECT (series));
+	if (parent_style->interesting_fields & GO_STYLE_MARKER)
+		style->interesting_fields = parent_style->interesting_fields & (GO_STYLE_MARKER | GO_STYLE_MARKER_NO_COLOR);
 	else
 		style->interesting_fields = parent_style->interesting_fields;
 	gog_theme_fillin_style (gog_object_get_theme (GOG_OBJECT (gso)),
@@ -1425,7 +1432,7 @@ gog_xy_series_element_class_init (GogXYSeriesElementClass *klass)
 
 GSF_DYNAMIC_CLASS (GogXYSeriesElement, gog_xy_series_element,
 	gog_xy_series_element_class_init, NULL,
-	GOG_SERIES_ELEMENT_TYPE)
+	GOG_TYPE_SERIES_ELEMENT)
 
 /****************************************************************************/
 
@@ -1437,9 +1444,9 @@ typedef struct {
 
 typedef GogObjectClass GogXYInterpolationClampsClass;
 
-#define GOG_XY_INTERPOLATION_CLAMPS_TYPE	(gog_xy_interpolation_clamps_get_type ())
-#define GOG_XY_INTERPOLATION_CLAMPS(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_XY_INTERPOLATION_CLAMPS_TYPE, GogXYInterpolationClamps))
-#define GOG_IS_XY_INTERPOLATION_CLAMPS(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_XY_INTERPOLATION_CLAMPS_TYPE))
+#define GOG_TYPE_XY_INTERPOLATION_CLAMPS	(gog_xy_interpolation_clamps_get_type ())
+#define GOG_XY_INTERPOLATION_CLAMPS(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_XY_INTERPOLATION_CLAMPS, GogXYInterpolationClamps))
+#define GOG_IS_XY_INTERPOLATION_CLAMPS(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_XY_INTERPOLATION_CLAMPS))
 GType gog_xy_interpolation_clamps_get_type (void);
 
 static GObjectClass *interp_parent_klass;
@@ -1464,8 +1471,8 @@ static void
 gog_xy_interpolation_clamps_dataset_dim_changed (GogDataset *set, int dim_i)
 {
 	GogXYInterpolationClamps *clamps = GOG_XY_INTERPOLATION_CLAMPS (set);
-	clamps->series->clamped_derivs[dim_i] = (IS_GO_DATA_SCALAR ((clamps->derivs + dim_i)->data))?
-		go_data_scalar_get_value (GO_DATA_SCALAR ((clamps->derivs + dim_i)->data)): 0.;
+	clamps->series->clamped_derivs[dim_i] = (GO_IS_DATA ((clamps->derivs + dim_i)->data))?
+		go_data_get_scalar_value ((clamps->derivs + dim_i)->data): 0.;
 	gog_object_request_update (GOG_OBJECT (clamps->series));
 }
 
@@ -1504,8 +1511,8 @@ gog_xy_interpolation_clamps_init (GogXYInterpolationClamps *clamps)
 
 GSF_CLASS_FULL (GogXYInterpolationClamps, gog_xy_interpolation_clamps,
 		NULL, NULL, gog_xy_interpolation_clamps_class_init, NULL,
-		gog_xy_interpolation_clamps_init, GOG_OBJECT_TYPE, 0,
-		GSF_INTERFACE (gog_xy_interpolation_clamps_dataset_init, GOG_DATASET_TYPE))
+		gog_xy_interpolation_clamps_init, GOG_TYPE_OBJECT, 0,
+		GSF_INTERFACE (gog_xy_interpolation_clamps_dataset_init, GOG_TYPE_DATASET))
 
 /****************************************************************************/
 
@@ -1547,7 +1554,7 @@ gog_xy_series_update (GogObject *obj)
 
 	/* update children */
 	for (ptr = obj->children; ptr != NULL; ptr = ptr->next)
-		if (!IS_GOG_SERIES_LINES (ptr->data))
+		if (!GOG_IS_SERIES_LINES (ptr->data))
 			gog_object_request_update (GOG_OBJECT (ptr->data));
 
 	/* queue plot for redraw */
@@ -1568,7 +1575,7 @@ gog_xy_series_init (GObject *obj)
 	(GOG_SERIES (series))->acceptable_children = GOG_SERIES_ACCEPT_TREND_LINE;
 	series->x_errors = series->y_errors = NULL;
 	series->hdroplines = series->vdroplines = NULL;
-	series->interpolation_props = g_object_new (GOG_XY_INTERPOLATION_CLAMPS_TYPE, NULL);
+	series->interpolation_props = g_object_new (GOG_TYPE_XY_INTERPOLATION_CLAMPS, NULL);
 	GOG_XY_INTERPOLATION_CLAMPS (series->interpolation_props)->series = series;
 	gog_dataset_set_dim (series->interpolation_props, 0, go_data_scalar_val_new (0.), NULL);
 	gog_dataset_set_dim (series->interpolation_props, 1, go_data_scalar_val_new (0.), NULL);
@@ -1598,7 +1605,7 @@ gog_xy_series_finalize (GObject *obj)
 }
 
 static void
-gog_xy_series_init_style (GogStyledObject *gso, GogStyle *style)
+gog_xy_series_init_style (GogStyledObject *gso, GOStyle *style)
 {
 	GogSeries *series = GOG_SERIES (gso);
 
@@ -1617,7 +1624,7 @@ gog_xy_series_init_style (GogStyledObject *gso, GogStyle *style)
 			style->line.dash_type = GO_LINE_NONE;
 
 		if (!plot->default_style_has_fill && style->fill.auto_type)
-			style->fill.type = GOG_FILL_STYLE_NONE;
+			style->fill.type = GO_STYLE_FILL_NONE;
 
 		if (plot->use_splines)
 			series->interpolation = GO_LINE_INTERPOLATION_SPLINE;
@@ -1627,7 +1634,7 @@ gog_xy_series_init_style (GogStyledObject *gso, GogStyle *style)
 			style->line.dash_type = GO_LINE_NONE;
 
 		if (!plot->default_style_has_fill && style->fill.auto_type)
-			style->fill.type = GOG_FILL_STYLE_NONE;
+			style->fill.type = GO_STYLE_FILL_NONE;
 	}
 }
 
@@ -1728,7 +1735,7 @@ invalid_toggled_cb (GtkToggleButton *btn, GObject *obj)
 
 static void
 gog_xy_series_populate_editor (GogObject *obj,
-			       GogEditor *editor,
+			       GOEditor *editor,
 			       GogDataAllocator *dalloc,
 			       GOCmdContext *cc)
 {
@@ -1736,15 +1743,15 @@ gog_xy_series_populate_editor (GogObject *obj,
 	GtkWidget *w;
 	char const *dir = go_plugin_get_dir_name (
 		go_plugins_get_plugin_by_id ("GOffice_plot_xy"));
-	char *path = g_build_filename (dir, "gog-xy-series-prefs.glade", NULL);
-	GladeXML *gui = go_libglade_new (path, "gog_xy_series_prefs", GETTEXT_PACKAGE, cc);
+	char *path = g_build_filename (dir, "gog-xy-series-prefs.ui", NULL);
+	GtkBuilder *gui = go_gtk_builder_new (path, GETTEXT_PACKAGE, cc);
 
 	g_free (path);
 
 	(GOG_OBJECT_CLASS(series_parent_klass)->populate_editor) (obj, editor, dalloc, cc);
 
 	if (gui != NULL) {
-		w = glade_xml_get_widget (gui, "invalid_as_zero");
+		w = go_gtk_builder_get_widget (gui, "invalid_as_zero");
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
 				(GOG_XY_SERIES (obj))->invalid_as_zero);
 		g_signal_connect (G_OBJECT (w),
@@ -1752,17 +1759,18 @@ gog_xy_series_populate_editor (GogObject *obj,
 			G_CALLBACK (invalid_toggled_cb), obj);
 		series = GOG_XY_SERIES (obj);
 
-		w = glade_xml_get_widget (gui, "gog_xy_series_prefs");
-		g_object_set_data_full (G_OBJECT (w),
-			"state", gui, (GDestroyNotify)g_object_unref);
+		w = go_gtk_builder_get_widget (gui, "gog_xy_series_prefs");
 
-		gog_editor_add_page (editor, w, _("Details"));
+		go_editor_add_page (editor, w, _("Details"));
+		g_object_unref (gui);
 	}
 
 	w = gog_error_bar_prefs (GOG_SERIES (obj), "x-errors", TRUE, dalloc, cc);
-	gog_editor_add_page (editor, w, _("X error bars"));
+	go_editor_add_page (editor, w, _("X error bars"));
+	g_object_unref (w);
 	w = gog_error_bar_prefs (GOG_SERIES (obj), "y-errors", FALSE, dalloc, cc);
-	gog_editor_add_page (editor, w, _("Y error bars"));
+	go_editor_add_page (editor, w, _("Y error bars"));
+	g_object_unref (w);
 }
 #endif
 
@@ -1818,7 +1826,7 @@ gog_xy_series_class_init (GogStyledObjectClass *gso_klass)
 
 	series_klass->has_interpolation = TRUE;
 	series_klass->has_fill_type	= TRUE;
-	series_klass->series_element_type = GOG_XY_SERIES_ELEMENT_TYPE;
+	series_klass->series_element_type = GOG_TYPE_XY_SERIES_ELEMENT;
 	series_klass->get_interpolation_params = gog_xy_series_get_interpolation_params;
 
 	gog_object_register_roles (gog_klass, roles, G_N_ELEMENTS (roles));
@@ -1827,13 +1835,13 @@ gog_xy_series_class_init (GogStyledObjectClass *gso_klass)
 		g_param_spec_object ("x-errors", 
 			_("X error bars"),
 			_("GogErrorBar *"),
-			GOG_ERROR_BAR_TYPE, 
+			GOG_TYPE_ERROR_BAR, 
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, SERIES_PROP_YERRORS,
 		g_param_spec_object ("y-errors", 
 			_("Y error bars"),
 			_("GogErrorBar *"),
-			GOG_ERROR_BAR_TYPE, 
+			GOG_TYPE_ERROR_BAR, 
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, SERIES_PROP_INVALID_AS_ZERO,
 		g_param_spec_boolean ("invalid-as-zero", 
@@ -1859,7 +1867,7 @@ gog_xy_series_class_init (GogStyledObjectClass *gso_klass)
 
 GSF_DYNAMIC_CLASS (GogXYSeries, gog_xy_series,
 	gog_xy_series_class_init, gog_xy_series_init,
-	GOG_SERIES_TYPE)
+	GOG_TYPE_SERIES)
 
 G_MODULE_EXPORT void
 go_plugin_init (GOPlugin *plugin, GOCmdContext *cc)
